@@ -1,21 +1,10 @@
 """Builder for Grade Reports."""
 import os
-import sys
 import pdb
-import shutil
+import sys
 import traceback
-import subprocess
-from glob import glob
 from itertools import groupby
 
-from jinja2 import Environment, FileSystemLoader, StrictUndefined
-try:
-    from bibtexparser.bwriter import BibTexWriter
-    from bibtexparser.bibdatabase import BibDatabase
-    HAVE_BIBTEX_PARSER = True
-except ImportError:
-    HAVE_BIBTEX_PARSER = False
-
 try:
     import numpy as np
 except ImportError:
@@ -26,56 +15,25 @@ try:
 except ImportError:
     st = None
 
-from regolith.tools import all_docs_from_collection, date_to_rfc822, rfc822now, gets, month_and_year
-from regolith.dates import date_to_float
-from regolith.sorters import doc_date_key, ene_date_key, category_val, \
-    level_val, id_key, date_key, position_key
+from regolith.basebuilder import LatexBuilderBase
+from regolith.tools import all_docs_from_collection, month_and_year
 
-LATEX_OPTS = ['-halt-on-error', '-file-line-error']
 
 def latex_safe(s):
     return s.replace('&', '\&').replace('$', '\$').replace('#', '\#')
 
 
-class GradeReportBuilder(object):
-
+class GradeReportBuilder(LatexBuilderBase):
     btype = 'grades'
 
-    def __init__(self, rc):
-        self.rc = rc
-        self.bldir = os.path.join(rc.builddir, self.btype)
-        self.env = Environment(loader=FileSystemLoader([
-                    'templates',
-                    os.path.join(os.path.dirname(__file__), 'templates'),
-                    ]),
-                    )
-        self.construct_global_ctx()
-        if HAVE_BIBTEX_PARSER:
-            self.bibdb = BibDatabase()
-            self.bibwriter = BibTexWriter()
-
     def construct_global_ctx(self):
-        self.gtx = gtx = {}
+        super().construct_global_ctx()
+        gtx = self.gtx
         rc = self.rc
-        gtx['len'] = len
         gtx['sum'] = sum
         gtx['zip'] = zip
-        gtx['True'] = True
-        gtx['False'] = False
-        gtx['None'] = None
-        gtx['sorted'] = sorted
-        gtx['groupby'] = groupby
         gtx['range'] = range
-        gtx['gets'] = gets
         gtx['id_key'] = lambda x: x['_id']
-        gtx['date_key'] = date_key
-        gtx['doc_date_key'] = doc_date_key
-        gtx['level_val'] = level_val
-        gtx['category_val'] = category_val
-        gtx['rfc822now'] = rfc822now
-        gtx['date_to_rfc822'] = date_to_rfc822
-        gtx['month_and_year'] = month_and_year
-        gtx['latex_safe'] = latex_safe
         gtx['all_docs_from_collection'] = all_docs_from_collection
         gtx['grades'] = list(all_docs_from_collection(rc.client, 'grades'))
         gtx['courses'] = list(all_docs_from_collection(rc.client, 'courses'))
@@ -88,8 +46,10 @@ class GradeReportBuilder(object):
         ctx.update(kwargs)
         ctx['rc'] = ctx.get('rc', self.rc)
         ctx['static'] = ctx.get('static',
-                               os.path.relpath('static', os.path.dirname(fname)))
-        ctx['root'] = ctx.get('root', os.path.relpath('/', os.path.dirname(fname)))
+                                os.path.relpath('static',
+                                                os.path.dirname(fname)))
+        ctx['root'] = ctx.get('root',
+                              os.path.relpath('/', os.path.dirname(fname)))
         try:
             result = template.render(ctx)
         except:
@@ -99,11 +59,6 @@ class GradeReportBuilder(object):
         with open(os.path.join(self.bldir, fname), 'wt') as f:
             f.write(result)
 
-    def build(self):
-        os.makedirs(self.bldir, exist_ok=True)
-        self.latex()
-        self.clean()
-
     def latex(self):
         rc = self.rc
         for course in self.gtx['courses']:
@@ -123,7 +78,8 @@ class GradeReportBuilder(object):
             for student_id in course['students']:
                 student_grade_list = list(filter(
                     (lambda x: (x['student'] == student_id and
-                               x['course'] == course_id)), self.gtx['grades']))
+                                x['course'] == course_id)),
+                    self.gtx['grades']))
                 student_grades = {k: [] for k in grouped_assignments.keys()}
                 for category, asngs in grouped_assignments.items():
                     for asgn in asngs:
@@ -144,7 +100,7 @@ class GradeReportBuilder(object):
                     student_grades=student_grades,
                     student_totals=student_totals,
                     student_wavg=student_wavg
-                    )
+                )
             max_wavg = max(student_wavgs)
             curve = 1.0 - max_wavg
             # Make grades
@@ -165,24 +121,6 @@ class GradeReportBuilder(object):
                             **students_kwargs[student_id])
                 self.pdf(base)
 
-    def pdf(self, base):
-        """Compiles latex files to PDF"""
-        self.run(['latex'] + LATEX_OPTS + [base + '.tex'])
-        self.run(['dvipdf', base])
-
-    def run(self, cmd):
-        subprocess.run(cmd, cwd=self.bldir, check=True)
-
-    def clean(self):
-        postfixes = ['*.dvi', '*.toc', '*.aux', '*.out', '*.log', '*.bbl',
-                     '*.blg', '*.log', '*.spl', '*~', '*.spl', '*.run.xml',
-                     '*-blx.bib']
-        to_rm = []
-        for pst in postfixes:
-            to_rm += glob(os.path.join(self.bldir, pst))
-        for f in set(to_rm):
-            os.remove(f)
-
     def makestats(self, course):
         """Returns a dictionary of statistics for a course whose keys are
         the assignments and whose values are a (mean-problem, std-problem,
@@ -192,7 +130,7 @@ class GradeReportBuilder(object):
         course_id = course['_id']
         for grade in self.gtx['grades']:
             if grade['course'] != course_id:
-                 continue
+                continue
             assignment_id = grade['assignment']
             if assignment_id not in scores:
                 scores[assignment_id] = []
@@ -210,13 +148,15 @@ class GradeReportBuilder(object):
             total_sig = np.std(total, axis=0)
             total_max_score = np.max(total, axis=0)
             total_norm = st.norm(total_mu, total_sig)
-            total_percent_above_60 = 1.0 - total_norm.cdf(0.6 * total_max_score)
-            total_percent_above_80 = 1.0 - total_norm.cdf(0.8 * total_max_score)
+            total_percent_above_60 = 1.0 - total_norm.cdf(
+                0.6 * total_max_score)
+            total_percent_above_80 = 1.0 - total_norm.cdf(
+                0.8 * total_max_score)
             stats[assignment_id] = (
                 mu, sig, max_score, percent_above_60, percent_above_80,
                 total_mu, total_sig, total_max_score, total_percent_above_60,
                 total_percent_above_80,
-                )
+            )
         # handle stats for ungraded assignments
         for assignment in self.gtx['assignments']:
             assignment_id = assignment['_id']
@@ -251,7 +191,7 @@ class GradeReportBuilder(object):
             cat.append(weight)
             totalweight += weight
             catfrac = sgtot / catmax
-            #cat.append(catfrac)
+            # cat.append(catfrac)
             wfrac = catfrac * weight
             cat.append(wfrac)
             totalfrac += wfrac
@@ -308,7 +248,8 @@ DEFAULT_LETTER_SCALE = (
     (0.63, "D"),
     (0.60, "D-"),
     (-1.0, "F"),
-    )
+)
+
 
 def find_letter_grade(score, scale=DEFAULT_LETTER_SCALE):
     """Finds the letter grade from a score and a value."""
