@@ -39,9 +39,13 @@ ON_POSIX = (os.name == 'posix')
 
 def dbdirname(db, rc):
     """Gets the database dir name."""
-    dbsdir = os.path.join(rc.builddir, '_dbs')
-    dbdir = os.path.join(dbsdir, db['name'])
-    return dbdir
+    if rc.local is False:
+        dbsdir = os.path.join(rc.builddir, '_dbs')
+        dbdir = os.path.join(dbsdir, db['name'])
+        return dbdir
+    else:
+        dbdir = os.path.join(db['url'], db['name'])
+        return dbdir
 
 
 def dbpathname(db, rc):
@@ -100,7 +104,7 @@ def month_and_year(m=None, y=None):
 
 
 def filter_publications(citations, authors, reverse=False, bold=True):
-    """Filter publications by the author(s)
+    """Filter publications by the author(s)/editor(s)
 
     Parameters
     ----------
@@ -115,7 +119,9 @@ def filter_publications(citations, authors, reverse=False, bold=True):
     """
     pubs = []
     for pub in citations:
-        if len(set(pub['author']) & authors) == 0:
+        if len(set(pub.get('author', []))
+               & set(pub.get('editor', []))
+               & authors) == 0:
             continue
         pub = deepcopy(pub)
         if bold:
@@ -219,10 +225,19 @@ def awards_grants_honors(p):
         }
         aghs.append(d)
     for x in p.get('service', []) + p.get('honors', []):
-        d = {'description': latex_safe(x['name']),
-             'year': x['year'],
-             '_key': date_to_float(x['year'], x.get('month', 0)),
-             }
+        d = {'description': latex_safe(x['name']), }
+        if 'year' in x:
+            d.update({'year': x['year'],
+                      '_key': date_to_float(x['year'],
+                                            x.get('month', 0))})
+        elif 'begin_year' in x and 'end_year' in x:
+            d.update({'year': '{}-{}'.format(x['begin_year'], x['end_year']),
+                      '_key': date_to_float(x['begin_year'],
+                                            x.get('month', 0))})
+        elif 'begin_year' in x:
+            d.update({'year': '{}'.format(x['begin_year']),
+                      '_key': date_to_float(x['begin_year'],
+                                            x.get('month', 0))})
         aghs.append(d)
     aghs.sort(key=(lambda x: x.get('_key', 0.0)), reverse=True)
     return aghs
@@ -235,7 +250,8 @@ def latex_safe(s):
     ----------
     s : str
     """
-    return s.replace('&', '\&').replace('$', '\$').replace('#', '\#')
+    return (s.replace('&', '\&').replace('$', '\$').replace('#', '\#')
+            .replace('_', '\_'))
 
 
 def make_bibtex_file(pubs, pid, person_dir='.'):
